@@ -17,7 +17,7 @@ _K = TypeVar("_K")
 _V = TypeVar("_V")
 _T = TypeVar("_T")
 
-FrozenList = Tuple[_T, ...]  # type: ignore[misc]
+FrozenList = Union[Tuple[_T, ...], Tuple[_T, ...]]
 
 
 @dataclass(frozen=True)
@@ -42,6 +42,10 @@ class FrozenDict(Mapping[_K, _V], _FrozenDict[_K, _V]):
         return f"{self.__class__.__name__}{self._dict}"
 
 
+def chain(unchained: FrozenList[FrozenList[_T]]) -> FrozenList[_T]:
+    return tuple(item for items in unchained for item in items)
+
+
 @overload
 def freeze(target: List[_T]) -> FrozenList[_T]:
     pass
@@ -58,3 +62,21 @@ def freeze(
     if isinstance(target, list):
         return tuple(target)
     return FrozenDict(target)
+
+
+@overload
+def unfreeze(target: FrozenList[_T]) -> List[_T]:
+    pass
+
+
+@overload
+def unfreeze(target: FrozenDict[_K, _V]) -> Dict[_K, _V]:
+    pass
+
+
+def unfreeze(
+    target: Union[FrozenList[_T], FrozenDict[_K, _V]]
+) -> Union[List[_T], Dict[_K, _V]]:
+    if isinstance(target, FrozenDict):
+        return {k: v for k, v in target.items()}
+    return [i for i in target]
