@@ -44,7 +44,7 @@ from typing import (
 )
 
 _T = TypeVar("_T")
-UnfoldResult = Result[_T, InvalidType]  # type: ignore[misc]
+UnfoldResult = Union[Result[_T, InvalidType], Result[_T, InvalidType]]
 
 
 @dataclass(frozen=True)
